@@ -68,8 +68,12 @@ class CmdPlots(CmdBase):
 
             if self.args.open:
                 import webbrowser
+                from platform import uname
 
-                opened = webbrowser.open(index_path)
+                if "Microsoft" in uname().release:
+                    url = Path(rel) / "index.html"
+
+                opened = webbrowser.open(url)
                 if not opened:
                     ui.error_write(
                         "Failed to open. Please try opening it manually."
@@ -183,7 +187,10 @@ def add_parser(subparsers, parent_parser):
     _add_output_arguments(plots_diff_parser)
     plots_diff_parser.set_defaults(func=CmdPlotsDiff)
 
-    PLOTS_MODIFY_HELP = "Modify display properties of plot metrics files."
+    PLOTS_MODIFY_HELP = (
+        "Modify display properties of data-series plots "
+        "(has no effect on image-type plots)."
+    )
     plots_modify_parser = plots_subparsers.add_parser(
         "modify",
         parents=[parent_parser],
