@@ -1,12 +1,10 @@
 import itertools
 import logging
-import os
 from concurrent.futures import ThreadPoolExecutor
 from contextlib import suppress
 from copy import copy
 from typing import TYPE_CHECKING, Optional
 
-from dvc.fs.local import LocalFileSystem
 from dvc.objects.errors import ObjectDBPermissionError, ObjectFormatError
 from dvc.objects.file import HashFile
 from dvc.progress import Tqdm
@@ -83,49 +81,26 @@ class ObjectDB:
         from_info: "AnyPath",
         to_info: "DvcPath",
         _hash_info: "HashInfo",
-        move: bool = False,
+        hardlink: bool = False,
     ):
+        from dvc import fs
+
         self.makedirs(to_info.parent)
-        use_move = isinstance(from_fs, type(self.fs)) and move
-        try:
-            if use_move:
-                self.fs.move(from_info, to_info)
-            elif isinstance(from_fs, LocalFileSystem):
-                if not isinstance(from_info, from_fs.PATH_CLS):
-                    from_info = from_fs.PATH_CLS(from_info)
-                self.fs.upload(from_info, to_info)
-            elif isinstance(self.fs, LocalFileSystem):
-                from_fs.download_file(from_info, to_info)
-            else:
-                with from_fs.open(from_info, mode="rb") as fobj:
-                    self.fs.upload_fobj(fobj, to_info)
-        except OSError as exc:
-            # If the target file already exists, we are going to simply
-            # ignore the exception (#4992).
-            #
-            # On Windows, it is not always guaranteed that you'll get
-            # FileExistsError (it might be PermissionError or a bare OSError)
-            # but all of those exceptions raised from the original
-            # FileExistsError so we have a separate check for that.
-            if isinstance(exc, FileExistsError) or (
-                os.name == "nt"
-                and exc.__context__
-                and isinstance(exc.__context__, FileExistsError)
-            ):
-                logger.debug("'%s' file already exists, skipping", to_info)
-                if use_move:
-                    from_fs.remove(from_info)
-            else:
-                raise
+        return fs.utils.transfer(
+            from_fs,
+            from_info,
+            self.fs,
+            to_info,
+            hardlink=hardlink,
+        )
 
     def add(
         self,
         path_info: "AnyPath",
         fs: "BaseFileSystem",
         hash_info: "HashInfo",
-        move: bool = True,
+        hardlink: bool = False,
         verify: Optional[bool] = None,
-        **kwargs,
     ):
         if self.read_only:
             raise ObjectDBPermissionError("Cannot add to read-only ODB")
@@ -139,7 +114,7 @@ class ObjectDB:
             pass
 
         cache_info = self.hash_to_path_info(hash_info.value)
-        self._add_file(fs, path_info, cache_info, hash_info, move)
+        self._add_file(fs, path_info, cache_info, hash_info, hardlink=hardlink)
 
         try:
             if verify:
@@ -149,10 +124,6 @@ class ObjectDB:
         except (ObjectFormatError, FileNotFoundError):
             pass
 
-        callback = kwargs.get("download_callback")
-        if callback:
-            callback(1)
-
     def hash_to_path_info(self, hash_) -> "DvcPath":
         return self.path_info / hash_[0:2] / hash_[2:]
 
