@@ -1,6 +1,13 @@
+from typing import TYPE_CHECKING, Optional
+
+from dvc.exceptions import FileTransferError, UploadError
+
 from ..utils import glob_targets
 from . import locked
 
+if TYPE_CHECKING:
+    from dvc.objects.db.base import ObjectDB
+
 
 @locked
 def push(
@@ -16,15 +23,18 @@ def push(
     run_cache=False,
     revs=None,
     glob=False,
+    odb: Optional["ObjectDB"] = None,
 ):
-    used_run_cache = self.stage_cache.push(remote) if run_cache else []
+    used_run_cache = (
+        self.stage_cache.push(remote, odb=odb) if run_cache else []
+    )
 
     if isinstance(targets, str):
         targets = [targets]
 
     expanded_targets = glob_targets(targets, glob=glob)
 
-    used = self.used_cache(
+    used = self.used_objs(
         expanded_targets,
         all_branches=all_branches,
         all_tags=all_tags,
@@ -38,4 +48,14 @@ def push(
         revs=revs,
     )
 
-    return len(used_run_cache) + self.cloud.push(used, jobs, remote=remote)
+    pushed = len(used_run_cache)
+    for dest_odb, obj_ids in used.items():
+        if dest_odb and dest_odb.read_only:
+            continue
+        try:
+            pushed += self.cloud.push(
+                obj_ids, jobs, remote=remote, odb=odb or dest_odb
+            )
+        except FileTransferError as exc:
+            raise UploadError(exc.amount)
+    return pushed
