@@ -2,7 +2,7 @@ import logging
 import os
 import tempfile
 from contextlib import contextmanager
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 
 from funcy import cached_property, first
 
@@ -10,6 +10,9 @@ from dvc.exceptions import DvcException
 from dvc.path_info import PathInfo
 from dvc.utils import dict_sha256, relpath
 
+if TYPE_CHECKING:
+    from dvc.objects.db.base import ObjectDB
+
 logger = logging.getLogger(__name__)
 
 
@@ -19,13 +22,11 @@ class RunCacheNotFoundError(DvcException):
 
 
 def _get_cache_hash(cache, key=False):
-    from dvc.hash_info import HashInfo
+    from dvc.objects.meta import Meta
 
     if key:
         cache["outs"] = [out["path"] for out in cache.get("outs", [])]
-    return dict_sha256(
-        cache, exclude=[HashInfo.PARAM_SIZE, HashInfo.PARAM_NFILES]
-    )
+    return dict_sha256(cache, exclude=[Meta.PARAM_SIZE, Meta.PARAM_NFILES])
 
 
 def _can_hash(stage):
@@ -231,10 +232,11 @@ class StageCache:
 
         return ret
 
-    def push(self, remote: Optional[str]):
+    def push(self, remote: Optional[str], odb: Optional["ObjectDB"] = None):
         from dvc.objects.transfer import _log_exceptions
 
-        odb = self.repo.cloud.get_remote_odb(remote)
+        if odb is None:
+            odb = self.repo.cloud.get_remote_odb(remote)
         return self._transfer(
             _log_exceptions(odb.fs.upload),
             self.repo.odb.local,
